{ Unit: BcComponentsRegister
  ===========================================================================

  The contents of this file are subject to the Bluecave Public License V 1.1
  (the "License"). You may not copy or use this file, in either source code
  or executable form, except in compliance with the License. You may obtain
  a copy of the License at http://www.bluecave.net/licenses/.

  Software distributed under the License is distributed on an "AS IS" basis,
  WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
  for the specific language governing rights and limitations under the
  License.

  Copyright (C) 2001 Bluecave Software. All Rights Reserved.
  http://www.bluecave.net/

  Copyright (C) 2001 Jouni Airaksinen. All Rights Reserved.
  http://Mintus.Codefield.com/ -- Mintus@Codefield.com

  ===========================================================================

  Unit description:

    Bluecave Components Register.

  History:

    2001-10-03: Initial version

  =========================================================================== }

{$I DFS.inc}
{$I BcDirectives.inc}

unit BcComponentsRegister;

interface

procedure Register;

implementation

uses
  SysUtils,
  Classes,
  ActnList,
  BcDialogs,
  BcPageControlLink,
  BcStringsContainer,
  BcWebLabel,
  BcThreadTimer,
  BcExplorerPanel,
  BcActionClasses,
  BcColorButton,
  BcFontButton,
  BcTrackBar,
  BcGroupBox,
  BcAPITimer,
  BcCheckBox;

type
  TBasicActionClassArray = array of TBasicActionClass;

  TBcActionRegisterClass = class(TObject)
    AClasses: TBasicActionClassArray;
    procedure GetActions(const Category: string; ActionClass: TBasicActionClass; Info: Pointer);
  end;

procedure Register;
begin
  RegisterComponents('Bluecave',
    [TBcOpenDialog,
    TBcSaveDialog,
    TBcPageControlLink,
    TBcStringsContainer,
    TBcWebLabel,
    TBcThreadTimer,
    TBcExplorerPanel,
    TBcColorButton,
    TBcFontButton,
    TBcTrackBar,
    TBcGroupBox,
    TBcAPITimer,
    TBcCheckBox]);
end;

procedure TBcActionRegisterClass.GetActions(const Category: string; ActionClass: TBasicActionClass; Info: Pointer);
begin
  SetLength(AClasses, Length(AClasses) + 1);
  AClasses[Length(AClasses) - 1] := ActionClass;
end;

{ Registers action classes only if they have not been already registered.
  Now if the package is recompiled you won't get duplicate actions. }
procedure RegisterActionsEx(const CategoryName: string;
  const AClasses: array of TBasicActionClass; Resource: TComponentClass);
var
  ActionRegisterObject: TBcActionRegisterClass;
  ARegisterClasses: TBasicActionClassArray;
  I, J: Integer;
  IsRegistered: Boolean;
begin
  try
    ActionRegisterObject := TBcActionRegisterClass.Create;
    EnumRegisteredActions(ActionRegisterObject.GetActions, nil);

    for J := Low(AClasses) to High(AClasses) do
    begin
      IsRegistered := False;
      for I := Low(ActionRegisterObject.AClasses) to High(ActionRegisterObject.AClasses) do
        if ActionRegisterObject.AClasses[I] = AClasses[J] then
        begin
          IsRegistered := True;
          Break;
        end;
      if not IsRegistered then
      begin
        SetLength(ARegisterClasses, Length(ARegisterClasses) + 1);
        ARegisterClasses[Length(ARegisterClasses) - 1] := AClasses[J];
      end;
    end;

    if Length(ActionRegisterObject.AClasses) > 0 then
      RegisterActions(CategoryName, ARegisterClasses, Resource);
  finally
    FreeAndNil(ActionRegisterObject);
  end;
end;

initialization
  RegisterActionsEx('', [TBcAction], nil);

finalization
//  UnRegisterActions([TBcAction]);

end.
