{ Unit: BcGroupBox
  ===========================================================================

  The contents of this file are subject to the Bluecave Limited License V 1.0
  (the "License"). You may not copy or use this file, in either source code
  or executable form, except in compliance with the License. You may obtain
  a copy of the License at http://www.bluecave.net/licenses/.

  Software distributed under the License is distributed on an "AS IS" basis,
  WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
  for the specific language governing rights and limitations under the
  License.

  Copyright (C) 2001-2002 Bluecave Software. All Rights Reserved.
  http://www.bluecave.net/

  Copyright (C) 2001-2002 Jouni Airaksinen. All Rights Reserved.
  http://Mintus.Codefield.com/ -- Mintus@Codefield.com

  ===========================================================================

  Unit description:

    Real groupbox control using the CommCtrl BUTTON SubClass. This makes
    the groupbox Windows XP Visual Styles compatible.

  History:

    2001-11-29:
      - Fixed bug which caused e.g. TLabel to leave "traces" to the
        groupbox under designtime.
      - published the Align property.
    2001-11-26: Initial version

  =========================================================================== }

{$I DFS.inc}
{$I BcDirectives.inc}

unit BcGroupBox;

interface

uses
  Windows, Messages, SysUtils, Classes, Controls, Forms, StdCtrls;

const
  DefaultBorderWidth = 8;

type
  TBcCustomGroupBox = class(TButtonControl)
  private
    FBorderWidth: Integer;
    function GetCaption: string;
    procedure SetCaption(const Value: string);
    procedure SetBorderWidth(const Value: Integer);
    { Private declarations }
  protected
    { Protected declarations }
    procedure CreateParams(var Params: TCreateParams); override;
    procedure AdjustClientRect(var Rect: TRect); override;
  public
    { Public declarations }
    constructor Create(AOwner: TComponent); override;
    property Caption: string read GetCaption write SetCaption;
    property BorderWidth: Integer read FBorderWidth write SetBorderWidth default DefaultBorderWidth;
  end;

  TBcGroupBox = class(TBcCustomGroupBox)
  published
    property Align;
    property Caption;
    property BorderWidth;
    property Action;
    property Anchors;
    property BiDiMode;
    property Constraints;
    property DragCursor;
    property DragKind;
    property DragMode;
    property Enabled;
    property Font;
    property ParentBiDiMode;
    property ParentFont;
    property ParentShowHint;
    property PopupMenu;
    property ShowHint;
    property TabOrder;
    property TabStop default False;
    property Visible;
    property OnClick;
    property OnContextPopup;
    property OnDragDrop;
    property OnDragOver;
    property OnEndDock;
    property OnEndDrag;
    property OnEnter;
    property OnExit;
    property OnKeyDown;
    property OnKeyPress;
    property OnKeyUp;
    property OnMouseDown;
    property OnMouseMove;
    property OnMouseUp;
    property OnStartDock;
    property OnStartDrag;
  end;

implementation

{ TBcGroupBox }

procedure TBcCustomGroupBox.AdjustClientRect(var Rect: TRect);
begin
  inherited AdjustClientRect(Rect);
  InflateRect(Rect, -BorderWidth, -BorderWidth);
  Inc(Rect.Top, 6); // top has higher border
end;

constructor TBcCustomGroupBox.Create(AOwner: TComponent);
begin
  inherited Create(AOwner);
  ControlStyle := [csSetCaption, {csOpaque,} csDoubleClicks, csAcceptsControls];
  Width := 185;
  Height := 105;
  FBorderWidth := DefaultBorderWidth;
  TabStop := False;
end;

procedure TBcCustomGroupBox.CreateParams(var Params: TCreateParams);
begin
  inherited CreateParams(Params);
  CreateSubClass(Params, 'BUTTON');
  Params.Style := Params.Style or BS_GROUPBOX;
end;

function TBcCustomGroupBox.GetCaption: string;
begin
  SetLength(Result, 512);
  SetLength(Result, GetWindowText(Handle, PChar(Result), 512));
end;

procedure TBcCustomGroupBox.SetBorderWidth(const Value: Integer);
begin
  FBorderWidth := Value;
  Realign;
end;

procedure TBcCustomGroupBox.SetCaption(const Value: string);
begin
  SetWindowText(Handle, PChar(Value));
  inherited Caption := Value;
end;

end.
